@@ -1,6 +1,6 @@
 package Bundle::Interchange;
 
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 1;
 
@@ -24,6 +24,8 @@ MIME::Base64
 
 MIME::Lite
 
+JSON
+
 URI::URL
 
 HTML::Tagset
@@ -64,6 +66,11 @@ Spreadsheet::WriteExcel
 
 Net::IP::Match::Regexp
 
+Digest::Bcrypt
+
+Crypt::Random
+
+
 =head1 DESCRIPTION
 
 This bundle installs the prerequisites for Interchange 5 as well as some
@@ -140,6 +147,14 @@ Not used otherwise.
 Helps Term::ReadLine::Perl generate completions and editing in makecat.
 Not used otherwise.
 
+=item Digest::Bcrypt
+
+Used for strong password encryption.
+
+=item Crypt::Random
+
+Used for strong password encryption.
+
 =back
 
 =head1 AUTHOR
